.. _top_{{objname}}:
.. role:: hidden
    :class: hidden-section
.. currentmodule:: {{ module }}


{{ name | underline}}

.. autoclass:: {{ objname }}

    .. rubric:: Reference Details


{% for item in members %}
{% if item in ['__call__'] %}
    .. automethod:: {{ objname }}.{{ item }}
{% endif %}
{% if "BaseRegularisation" in objname and item == '__add__' %}
    .. automethod:: {{ objname }}.{{ item }}
{% endif %}
{% endfor %}



{% for item in methods %}

{% if "BaseSolver" in objname and item == '__init__' %}
    .. automethod:: {{ objname }}.{{ item }}
{% endif %}

{% if item != '__init__' %}
    .. automethod:: {{ objname }}.{{ item }}
{% endif %}
{% endfor %}



{% for item in attributes %}
    .. autoattribute:: {{ objname }}.{{ item }}
{% endfor %}

:ref:`back to top <top_{{objname}}>`


{% if objname == 'InversionResult' %}
----

.. autoclass:: cofi.SamplingResult

    .. rubric:: Reference Details

    .. automethod:: cofi.SamplingResult.to_arviz

:ref:`back to top <top_{{objname}}>`
{% endif %}



.. autogenerated from _templates/autosummary/class.rst